==> guile-2.0.11-4-armv7h.pkg.tar.xz: usr/lib/guile/2.0/ccache/srfi/srfi-31.go <==
GOOF----LE-4-2.04	      ] O 4       hC      ] g  guile	 	g  define-module*	 	 	g  srfi	g  srfi-31	 		g  filenameS	
f  srfi/srfi-31.scm	g  exportsS	g  rec	
 	g  set-current-module	 	 	g  cond-expand-provide	g  current-module	 	g  make-syntax-transformer	 	 	g  macro	g  $sc-dispatch	 	 	g  any		g  each-any			 g  
syntax-object	!g  letrec	"g  top	#" 	$g  ribcage	%g  dummy	&g  name	'g  formals	(g  body	)%&'( 	*g  m-AQxPK0c53@skwRidJtCJdI-1626	+*" 	,+### 	-f  l-AQxPK0c53@skwRidJtCJdI-1631	.f  l-AQxPK0c53@skwRidJtCJdI-1632	/f  l-AQxPK0c53@skwRidJtCJdI-1633	0f  l-AQxPK0c53@skwRidJtCJdI-1634	1-./0 	2$),1 	3$ 	4g  x	54 	6+ 	7f  l-AQxPK0c53@skwRidJtCJdI-1628	87 	9$568 	:#239 	;g  hygiene	<; 	= !:< 	>g  lambda	? >:< 	@ 	Ag  expr	B%&A 	C+## 	Df  l-AQxPK0c53@skwRidJtCJdI-1641	Ef  l-AQxPK0c53@skwRidJtCJdI-1642	Ff  l-AQxPK0c53@skwRidJtCJdI-1643	GDEF 	H$BCG 	I#H39 	J !I< 	Kg  syntax-violation	LK 	MK 	Nf  -source expression failed to match any patternC 5h  r   ]4	

5 4 >  "  G   4i4i5 >  "  G  4=? h    f   ]   C      ^       g  dummy
		 g  name		 g  formals			 g  body			  			   C@J  h   Q   ]   C    I       g  dummy
		 g  name		 g  expr			  			   CMN        h@   I  ]4 5$  @4 5$  @ 6       A      g  x
		9 g  tmp		9 g  tmp		"	9  g  filenamef  srfi/srfi-31.scm
		 		9  g  
documentationf  XReturn the given object, defined in a lexical environment where
NAME is bound to itself.g  
macro-typeg  syntax-rulesg  patternsg  nameg  formalsg  bodyg  ... g  nameg  expr   C5RCj       g  m
		(  g  filenamef  srfi/srfi-31.scm		
	)	
	.			6		&	;	
 	
   C6 

==> guile-2.0.12-1-armv7h.pkg.tar.xz: usr/lib/guile/2.0/ccache/srfi/srfi-31.go <==
GOOF----LE-4-2.04	      ] O 4       hC      ] g  guile	 	g  define-module*	 	 	g  srfi	g  srfi-31	 		g  filenameS	
f  srfi/srfi-31.scm	g  exportsS	g  rec	
 	g  set-current-module	 	 	g  cond-expand-provide	g  current-module	 	g  make-syntax-transformer	 	 	g  macro	g  $sc-dispatch	 	 	g  any		g  each-any			 g  
syntax-object	!g  letrec	"g  top	#" 	$g  ribcage	%g  dummy	&g  name	'g  formals	(g  body	)%&'( 	*g  m-Rsv5EBOGuxehzV@lk9m1sS-1587	+*" 	,+### 	-f  l-Rsv5EBOGuxehzV@lk9m1sS-1592	.f  l-Rsv5EBOGuxehzV@lk9m1sS-1593	/f  l-Rsv5EBOGuxehzV@lk9m1sS-1594	0f  l-Rsv5EBOGuxehzV@lk9m1sS-1595	1-./0 	2$),1 	3$ 	4g  x	54 	6+ 	7f  l-Rsv5EBOGuxehzV@lk9m1sS-1589	87 	9$568 	:#239 	;g  hygiene	<; 	= !:< 	>g  lambda	? >:< 	@ 	Ag  expr	B%&A 	C+## 	Df  l-Rsv5EBOGuxehzV@lk9m1sS-1602	Ef  l-Rsv5EBOGuxehzV@lk9m1sS-1603	Ff  l-Rsv5EBOGuxehzV@lk9m1sS-1604	GDEF 	H$BCG 	I#H39 	J !I< 	Kg  syntax-violation	LK 	MK 	Nf  -source expression failed to match any patternC 5h  r   ]4	

5 4 >  "  G   4i4i5 >  "  G  4=? h    f   ]   C      ^       g  dummy
		 g  name		 g  formals			 g  body			  			   C@J  h   Q   ]   C    I       g  dummy
		 g  name		 g  expr			  			   CMN        h@   I  ]4 5$  @4 5$  @ 6       A      g  x
		9 g  tmp		9 g  tmp		"	9  g  filenamef  srfi/srfi-31.scm
		 		9  g  
documentationf  XReturn the given object, defined in a lexical environment where
NAME is bound to itself.g  
macro-typeg  syntax-rulesg  patternsg  nameg  formalsg  bodyg  ... g  nameg  expr   C5RCj       g  m
		(  g  filenamef  srfi/srfi-31.scm		
	)	
	.			6		&	;	
 	
   C6 
